pub struct GitHubConnectorConfig {
pub orgs: Vec<String>,
pub users: Vec<String>,
pub enterprise_url: Option<String>,
pub concurrent_requests: usize,
}Expand description
The primary configuration block for the GithubConnector.
Fields
orgs: Vec<String>A list of organization slugs that this connector should try and connect to and work with.
users: Vec<String>A list of user logins that this connector should manage resources under.
enterprise_url: Option<String>If using Github enterprise, the url for the enterprise
concurrent_requests: usizeThe number of requests to make in parallel. Defaults to 5.
Implementations