pub struct BranchProtection {
pub required_status_checks: Option<RequiredStatusChecks>,
pub enforce_admins: bool,
pub required_pull_request_reviews: Option<PullRequestReviewEnforcement>,
pub restrictions: Option<BranchRestrictions>,
pub required_linear_history: bool,
pub allow_force_pushes: bool,
pub allow_deletions: bool,
pub block_creations: bool,
pub required_conversation_resolution: bool,
pub lock_branch: bool,
pub allow_fork_syncing: bool,
}Expand description
Branch protection rules that control how a branch can be modified
Fields
required_status_checks: Option<RequiredStatusChecks>Status checks that must pass before merging
enforce_admins: boolWhether to enforce all configured restrictions for administrators
required_pull_request_reviews: Option<PullRequestReviewEnforcement>Pull request review requirements
restrictions: Option<BranchRestrictions>Restrictions on who can push to the branch
required_linear_history: boolWhether to require a linear commit history (no merge commits)
allow_force_pushes: boolWhether to allow force pushes to the branch
allow_deletions: boolWhether to allow branch deletions
block_creations: boolWhether to block creation of matching branches
required_conversation_resolution: boolWhether to require all conversations on code to be resolved before merging
lock_branch: boolWhether to lock the branch, making it read-only
allow_fork_syncing: boolWhether to allow users with push access to sync from upstream forks