pub struct PullRequestReviewEnforcement {
pub required_approving_review_count: u32,
pub dismiss_stale_reviews: bool,
pub require_code_owner_reviews: bool,
pub require_last_push_approval: bool,
}Expand description
Pull request review enforcement settings for branch protection
Fields
required_approving_review_count: u32The number of approving reviews required before a pull request can be merged
dismiss_stale_reviews: boolWhether to dismiss approving reviews when new commits are pushed
require_code_owner_reviews: boolWhether to require review from code owners
require_last_push_approval: boolWhether to require approval of the most recent reviewable push