pub struct RequiredStatusChecks {
pub strict: bool,
pub contexts: Vec<String>,
}Expand description
Required status checks that must pass before merging a pull request
Fields
strict: boolWhether to require branches to be up to date before merging
contexts: Vec<String>The list of status checks that must pass before branches can be merged